@@ -12,6 +12,7 @@ SERVICE_PATH = 'path'
 SERVICE_SKITCH = 'skitch'
 SERVICE_MINUS = 'minus'
 SERVICE_CLOUD = 'cloud'
+SERVICE_500PX = '500px'
 
 def set_natural_num(val):
     """
@@ -71,6 +72,8 @@ class WebImagery():
                     return page('link[rel="image_src"]').attr('href')
                 elif self.service == SERVICE_CLOUD:
                     return page('#content img').attr('src')
+                elif self.service == SERVICE_500PX:
+                    return page('#mainphoto').attr('src')
                 else:
                     return ""
         except:
@@ -108,6 +111,8 @@ class WebImagery():
                     return '<img src="'+page('link[rel="image_src"]').attr('href')+'" alt="'+alt+'" width="'+str(self.width)+'" height="'+str(self.height)+'" />'
                 elif self.service == SERVICE_CLOUD:
                     return '<img src="'+page('#content img').attr('src')+'" alt="'+alt+'" width="'+str(self.width)+'" height="'+str(self.height)+'" />'
+                elif self.service == SERVICE_500PX:
+                    return '<img src="'+page('#mainphoto').attr('src')+'" alt="'+alt+'" width="'+str(self.width)+'" height="'+str(self.height)+'" />'
                 else:
                     return ""
         except:
@@ -147,5 +152,8 @@ class WebImagery():
         elif 'cl.ly' in url.netloc:
             self.service = SERVICE_CLOUD
             return True 
+        elif '500px' in url.netloc:
+            self.service == SERVICE_500PX
+            return True
         else:
             return False
\ No newline at end of file
